--------------------------------------------------------------------------------
-- Weapon Recycle Bin + projectile sheet of paper
-- Script originally by DC, August 2009, www.UnrealSoftware.de
-- edited by Kiffer-Opa
-- recycle bin and sheet of paper graphics by Yellowicon <http://www.yellowicon.com/>
-- version 1.1
-------------------------------------------------------------------------------

-- Setup Tables
if kifferopa==nil then kifferopa={} end
kifferopa.recyclebin={}
kifferopa.recyclebin.recyclebin={}
kifferopa.recyclebin.cluster={}

-- Load & Prepare Ressources
setblend(blend_alpha)
setalpha(1)
setcolor(255,255,255)
kifferopa.recyclebin.gfx_wpn=loadgfx("weapons/recyclebin.png")						-- Weapon Image
kifferopa.recyclebin.gfx_icon=loadgfx("weapons/recyclebin_icon.png")
kifferopa.recyclebin.gfx_cluster=loadgfx("weapons/recyclebin_document.png")
setmidhandle(kifferopa.recyclebin.gfx_wpn)
setmidhandle(kifferopa.recyclebin.gfx_icon)
kifferopa.recyclebin.sfx_attack=loadsfx("throw.ogg")							-- Attack Sound
kifferopa.recyclebin.sfx_bounce=loadsfx("bounce.wav")							-- Bounce Sound

--------------------------------------------------------------------------------
-- Weapon: recyclebin
--------------------------------------------------------------------------------

kifferopa.recyclebin.id=addweapon("kifferopa.recyclebin","Recycle Bin",kifferopa.recyclebin.gfx_icon,0,3)	-- Add Weapon

function kifferopa.recyclebin.draw()													-- Draw
	if getplayeraction(0)==0 and weapon_shots<=0 then
		setblend(blend_alpha)
		setalpha(1)
		setcolor(255,255,255)
		setscale(1,1)
		setrotation(0)
		drawimage(kifferopa.recyclebin.gfx_wpn,getplayerx(0)+getplayerdirection(0)*7,getplayery(0)+2)
	end
end

function kifferopa.recyclebin.attack(attack)											-- Attack
	if (weapon_shots<=0) then
		if attack==1 then
			-- No more weapon switching!
			useweapon(0)
			playsound(kifferopa.recyclebin.sfx_attack)
			weapon_shots=weapon_shots+1
			id=createprojectile(kifferopa.recyclebin.recyclebin.id)
			projectiles[id]={}
			-- Ignore collision with current player at beginning
			projectiles[id].ignore=playercurrent()
			-- Set initial position of projectile
			projectiles[id].x=getplayerx(0)+getplayerdirection(0)*7
			projectiles[id].y=getplayery(0)+2
			-- Set speed of projectile
			projectiles[id].sx=getplayerdirection(0)*2
			projectiles[id].sy=-1
			-- Set timer
			projectiles[id].timer=3*50
			

			
			-- End Turn
			endturn()
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: recyclebin
--------------------------------------------------------------------------------

kifferopa.recyclebin.recyclebin.id=addprojectile("kifferopa.recyclebin.recyclebin")	-- Add Projectile

function kifferopa.recyclebin.recyclebin.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	setrotation(0)
	-- Fuse Sound

	-- Draw projectile
	drawimage(kifferopa.recyclebin.gfx_wpn,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function kifferopa.recyclebin.recyclebin.update(id)					-- Update

	-- Gravity influence on speed + decrease x speed
	projectiles[id].sx=projectiles[id].sx*0.95
	projectiles[id].sy=projectiles[id].sy+getgravity()
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		-- Move X
		projectiles[id].x=projectiles[id].x+msubx
		if collision(kifferopa.recyclebin.gfx_wpn,projectiles[id].x,projectiles[id].y,1,1)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				if (math.abs(projectiles[id].sx)>0.5) then playsound(kifferopa.recyclebin.sfx_bounce) end
				projectiles[id].x=projectiles[id].x-msubx
				projectiles[id].sx=-projectiles[id].sx*0.05
				msubx=-msubx*0.05
			end
		else
			projectiles[id].ignore=0
		end
		-- Move Y
		projectiles[id].y=projectiles[id].y+msuby
		if collision(kifferopa.recyclebin.gfx_wpn,projectiles[id].x,projectiles[id].y,1,1)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				if (math.abs(projectiles[id].sy)>0.5) then playsound(kifferopa.recyclebin.sfx_bounce) end
				projectiles[id].y=projectiles[id].y-msuby
				projectiles[id].sy=-projectiles[id].sy*0.3
				msuby=-msuby*0.3
			end
		else
			projectiles[id].ignore=0
		end		
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			stopchannel(0)
			-- Free projectile
			freeprojectile(id)
			break
		end
	end
	-- Timer -> Explode
	projectiles[id].timer=projectiles[id].timer-1
	if projectiles[id].timer<=0 then
		-- Cause damage
		arealdamage(projectiles[id].x,projectiles[id].y,125,65)
		-- Destroy terrain
		terrainexplosion(projectiles[id].x,projectiles[id].y,55,1)
		-- Crater
		grey=math.random(0,40)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater200,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		else
			terrainalphaimage(gfx_crater175,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		end
		
		-- Free projectile
		freeprojectile(id)
		
		-- Spawn Clusters
		math.randomseed(projectiles[id].x*3+projectiles[id].y)
		for i=1,3,1 do
			pid=createprojectile(kifferopa.recyclebin.cluster.id)
			projectiles[pid]={}
			projectiles[pid].x=projectiles[id].x+math.random(-30,40)*0.1
			projectiles[pid].y=projectiles[id].y+math.random(-30,-20)*0.1
			projectiles[pid].sx=math.random(-40,40)*0.1
			projectiles[pid].sy=math.random(-50,-10)*0.1
			if i==0 then projectiles[pid].follow=1 end
		end
	end
	-- Scroll to projectile
	scroll(projectiles[id].x,projectiles[id].y)
end


-------------------------------------------------------------------------------
-- Projectile: Document cluster
--------------------------------------------------------------------------------

kifferopa.recyclebin.cluster.id=addprojectile("kifferopa.recyclebin.cluster")		-- Add Projectile

function kifferopa.recyclebin.cluster.draw(id)								-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(kifferopa.recyclebin.gfx_cluster,projectiles[id].x,projectiles[id].y)
end

function kifferopa.recyclebin.cluster.update(id)								-- Update
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	
	
	
	-- Wind + Gravity influence on speed
	projectiles[id].sx=projectiles[id].sx+getwind()*0.4
	projectiles[id].sy=projectiles[id].sy+getgravity()
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby
		-- Collision
		if collision(col3x3,projectiles[id].x,projectiles[id].y,1,1)==1 then
			-- Cause damage
			arealdamage(projectiles[id].x,projectiles[id].y,50,50)
			-- Destroy terrain
			terrainexplosion(projectiles[id].x,projectiles[id].y,50,1)
			-- Crater
			grey=math.random(0,40)
			if math.random(0,1)==1 then
				terrainalphaimage(gfx_crater200,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
			else
				terrainalphaimage(gfx_crater175,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
			end
			-- Free projectile
			freeprojectile(id)
			break
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			-- Free projectile
			freeprojectile(id)
			break
		end
	end
	-- Scroll to projectile
	if projectiles[id].follow==1 then
		scroll(projectiles[id].x,projectiles[id].y)
	end
end
